@@ -44,15 +44,19 @@ dir.setNameFilters(QStringList()<<"*.bin"<<"*.iso"<<"*.img");
 
          QMenu *fsk=new QMenu(tr("Frameskip"));
          QActionGroup *gr=new QActionGroup(fsk);
-         for (int i=0;i<=8;i++){
-
-             QAction *nm=fsk->addAction(QString("%1").arg(i),this,SLOT(fm_skip_ch()));
+         for (int i=-1;i<=8;i++){
+QString nam=QString("%1").arg(i);
+if (i==-1)nam="Auto";
+if (i==0)nam="Off";
+             QAction *nm=fsk->addAction(nam,this,SLOT(fm_skip_ch()));
              nm->setActionGroup(gr);
              nm->setCheckable(true);
              if (i==frameskiping)nm->setChecked(true);
 
          }
 
+
+
          QActionGroup *gr2=new QActionGroup(fsk);
 
          QMenu *cml=new QMenu(tr("Cycle multiplier"));
@@ -309,7 +313,8 @@ arguments << "-runcd"<<"-load"<<QString("%1").arg(save_slot);
 
 
 
-if (frameskiping!=0)arguments<<"-frameskip"<<QString("%1").arg(frameskiping);
+if (frameskiping>0)arguments<<"-frameskip"<<QString("%1").arg(frameskiping);
+if (frameskiping==-1)arguments<<"-autoskip";
 if (cycle!=0)arguments<<"-cyclemult"<<QString("%1").arg(cycle);
 
 if (ui->checkBox->isChecked())arguments<<"-nosound";
