@@ -21,13 +21,22 @@ public:
     keys *keyopt;
     bool fps_show;
     bool abbey;
-    int cycle,frameskiping;
+    bool logged;
+    bool fscreen;
+    int cycle,frameskiping,save_slot;
 private:
     QMenu opt;
     QAction *fpsm;
     QAction *abbm;
+    //QAction *ldbg;
+    QAction *fscr;
+    QAction *eas;
 public slots:
+   // void show_log();
+   // void bug();
+    void about();
     void fm_skip_ch();
+    void save_ch();
     void cml_ch();
     void runGame();
     void select_dir();
